==> haskell-control-monad-free-0.6.2-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-control-monad-free.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 control-monad-free
version:              0.6.2
visibility:           public
id:                   control-monad-free-0.6.2-4g1zoX7nzgVIp8noozRTGL
key:                  control-monad-free-0.6.2-4g1zoX7nzgVIp8noozRTGL
license:              LicenseRef-PublicDomain
maintainer:           pepeiborra@gmail.com
author:               Luke Palmer, Pepe Iborra
stability:            stable
homepage:             http://github.com/pepeiborra/control-monad-free
synopsis:             Free monads and monad transformers
description:
    This package provides datatypes to construct Free monads,
    Free monad transformers, and useful instances. In addition it
    provides the constructs to avoid quadratic complexity of left
    associative bind, as explained in:

    * Janis Voigtlander, /Asymptotic Improvement of Computations over Free Monads, MPC'\''08/

category:             Control, Monads
abi:                  ad43dc84f1614628e1e9f28330be6cdb
exposed:              True
exposed-modules:
    Control.Monad.Free Control.Monad.Free.Improve
    Control.Monad.Free.Zip

import-dirs:          /usr/lib/ghc-9.0.1/site-local/control-monad-free-0.6.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/control-monad-free-0.6.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/control-monad-free-0.6.2
hs-libraries:         HScontrol-monad-free-0.6.2-4g1zoX7nzgVIp8noozRTGL
depends:              base-4.15.0.0 transformers-0.5.6.2
haddock-interfaces:
    /usr/share/doc/haskell-control-monad-free/html/control-monad-free.haddock

haddock-html:         /usr/share/doc/haskell-control-monad-free/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-control-monad-free-0.6.2-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-control-monad-free.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 control-monad-free
version:              0.6.2
visibility:           public
id:                   control-monad-free-0.6.2-EJKsSR16nS4LmOlWKhXJwz
key:                  control-monad-free-0.6.2-EJKsSR16nS4LmOlWKhXJwz
license:              LicenseRef-PublicDomain
maintainer:           pepeiborra@gmail.com
author:               Luke Palmer, Pepe Iborra
stability:            stable
homepage:             http://github.com/pepeiborra/control-monad-free
synopsis:             Free monads and monad transformers
description:
    This package provides datatypes to construct Free monads,
    Free monad transformers, and useful instances. In addition it
    provides the constructs to avoid quadratic complexity of left
    associative bind, as explained in:

    * Janis Voigtlander, /Asymptotic Improvement of Computations over Free Monads, MPC'\''08/

category:             Control, Monads
abi:                  58be08d01db301781dfb1ec7353632c3
exposed:              True
exposed-modules:
    Control.Monad.Free Control.Monad.Free.Improve
    Control.Monad.Free.Zip

import-dirs:          /usr/lib/ghc-9.0.2/site-local/control-monad-free-0.6.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/control-monad-free-0.6.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/control-monad-free-0.6.2
hs-libraries:         HScontrol-monad-free-0.6.2-EJKsSR16nS4LmOlWKhXJwz
depends:              base-4.15.1.0 transformers-0.5.6.2
haddock-interfaces:
    /usr/share/doc/haskell-control-monad-free/html/control-monad-free.haddock

haddock-html:         /usr/share/doc/haskell-control-monad-free/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
